"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = debounce;


/**
 * Delay the execution of any asynchronous validations
 * First update the state
 * then delay the validation according to the given delay value.
 *
 * @param {String} name field name
 * @param {Function} onChange the internal update function
 * @param {Function} runAsync an internal function that take async functions and calls them with the value and state.
 * @returns {Function}
 */
function debounce(name, onChange, runAsync) {
  var timeout = void 0;
  /**
   * @param {Function} fn the asynchronous function to be called
   * @param {Number} delay delaying running the asynchronous function in ms.
   * @param {Array} types possible types to override the onChnage defaults [UPDATE_FIELD, VALIDATE_FIELD]
   * @returns {Function}
   */
  return function f1(fn, delay) {
    var types = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

    return function f2(e) {
      e.preventDefault();
      var value = e.target.value;
      onChange(name, value, types);
      clearTimeout(timeout);
      timeout = setTimeout(function () {
        return runAsync(fn, name, value);
      }, delay);
    };
  };
}